Money : An amount of money, including units in the form of currency.
Fields
currency_code: Option<String>Three digit currency code in ISO 4217 format. String of length 3.
amount: Option<String>A decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Implementations